@@ -3,6 +3,8 @@ from .api_wrapper import SalesforceApiWrapper
 from langchain_core.tools import BaseTool, BaseToolkit
 from ..base.tool import BaseAction
 from pydantic import create_model, BaseModel, ConfigDict, Field
+
+from ..elitea_base import filter_missconfigured_index_tools
 from ..utils import clean_string, TOOLKIT_SPLITTER,get_max_toolkit_length
 from ...configurations.salesforce import SalesforceConfiguration
 
@@ -35,6 +37,7 @@ class SalesforceToolkit(BaseToolkit):
         )
 
     @classmethod
+    @filter_missconfigured_index_tools
     def get_toolkit(cls, selected_tools: list[str] | None = None, toolkit_name: Optional[str] = None, **kwargs):
         if selected_tools is None:
             selected_tools = []
